# simpleobsws
A simple obs-websocket library in Python for people who just want JSON output. Core code inspired by [obs-websocket-py](https://github.com/Elektordi/obs-websocket-py)

## Installing:
`pip install obs-ws-py-simple` [PyPi Link](https://pypi.org/project/simpleobsws/)

## Docs:
- Library docs: Not yet
- obs-websocket docs: https://github.com/Palakis/obs-websocket/blob/4.x-current/docs/generated/protocol.md

## Samples:
Samples are located in the samples folder [here.](/samples)
